@@ -26,7 +26,7 @@ atk_role_get_type (void)
   if (etype == 0) {
     static const GEnumValue values[] = {
       { ATK_ROLE_INVALID, "ATK_ROLE_INVALID", "invalid" },
-      { ATK_ROLE_ACCEL_LABEL, "ATK_ROLE_ACCEL_LABEL", "accel-label" },
+      { ATK_ROLE_ACCEL_LABEL, "ATK_ROLE_ACCEL_LABEL", "accelerator-label" },
       { ATK_ROLE_ALERT, "ATK_ROLE_ALERT", "alert" },
       { ATK_ROLE_ANIMATION, "ATK_ROLE_ANIMATION", "animation" },
       { ATK_ROLE_ARROW, "ATK_ROLE_ARROW", "arrow" },
@@ -303,6 +303,23 @@ atk_text_boundary_get_type (void)
   return etype;
 }
 GType
+atk_text_granularity_get_type (void)
+{
+  static GType etype = 0;
+  if (etype == 0) {
+    static const GEnumValue values[] = {
+      { ATK_TEXT_GRANULARITY_CHAR, "ATK_TEXT_GRANULARITY_CHAR", "char" },
+      { ATK_TEXT_GRANULARITY_WORD, "ATK_TEXT_GRANULARITY_WORD", "word" },
+      { ATK_TEXT_GRANULARITY_SENTENCE, "ATK_TEXT_GRANULARITY_SENTENCE", "sentence" },
+      { ATK_TEXT_GRANULARITY_LINE, "ATK_TEXT_GRANULARITY_LINE", "line" },
+      { ATK_TEXT_GRANULARITY_PARAGRAPH, "ATK_TEXT_GRANULARITY_PARAGRAPH", "paragraph" },
+      { 0, NULL, NULL }
+    };
+    etype = g_enum_register_static ("AtkTextGranularity", values);
+  }
+  return etype;
+}
+GType
 atk_text_clip_type_get_type (void)
 {
   static GType etype = 0;
